@@ -68,6 +68,7 @@ describe 'nova::compute::libvirt' do
           :libvirt_cpu_model                          => 'kvm64',
           :libvirt_disk_cachemodes                    => ['file=directsync','block=none'],
           :libvirt_hw_disk_discard                    => 'unmap',
+          :libvirt_hw_machine_type                    => 'x86_64=machinetype1,armv7l=machinetype2',
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
           :remove_unused_original_minimum_age_seconds => 3600,
@@ -88,6 +89,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
+      it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
       it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
@@ -123,14 +125,6 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_value('kvm64')}
     end
 
-    describe 'with qemu as virt_type' do
-      let :params do
-        { :libvirt_virt_type => 'qemu' }
-      end
-
-      it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('none')}
-    end
-
     describe 'with migration_support enabled' do
 
       context 'with vncserver_listen set to 0.0.0.0' do
